@@ -1,5 +1,9 @@
+mod constants;
+mod single_worker;
 mod thread_pool;
+mod types;
 mod worker_pool;
 
+pub use self::single_worker::SingleWorker;
 pub use self::thread_pool::{ExecuteError, ThreadPool};
 pub use self::worker_pool::{MessageSender, QueueError, WorkerPool};
